@@ -367,6 +367,44 @@ class CodeEditor (gtksourceview2.View):
       buffer.set_text(re.sub('\n\s+\n','\n\n',buffer.get_text(start,end)))
       buffer.place_cursor(buffer.get_iter_at_offset(offset))
 
+  #############################################################################
+  # @brief Replace tabulation
+  #############################################################################
+  def replace_tabs (self):
+    buffer = self.get_buffer()
+    prefs = Preferences()
+    prefs.load()
+    if prefs.use_space == True:
+      tabul=' ' * prefs.tab_width
+    else:
+      tabul='\t'
+    start,end=buffer.get_bounds()
+    text = buffer.get_text(start,end)
+    text = text.replace('\t',tabul)
+    buffer.set_text(text)
+
+  #############################################################################
+  # @brief DUPLICATE Line
+  #############################################################################
+  def duplicate_line (self):
+    buffer = self.get_buffer()
+
+    if (buffer.get_selection_bounds()!=()):
+      start,end=buffer.get_selection_bounds()
+      for line in range(start.get_line(),end.get_line()+1):
+        text = buffer.get_text(buffer.get_iter_at_line(line),buffer.get_iter_at_line(line+1))
+        buffer.insert(buffer.get_iter_at_line(line),text)
+    else:
+      insert = buffer.get_iter_at_mark(buffer.get_insert())
+      start = buffer.get_iter_at_line(insert.get_line())
+      end = buffer.get_iter_at_line(insert.get_line()+1)
+      text = ''
+      if start.get_line() == end.get_line():
+        _,end = buffer.get_bounds()
+        text = '\n'
+      text = text+buffer.get_text(start,end)
+      buffer.insert(buffer.get_iter_at_line(insert.get_line()),text)
+
   #############################################################################
   # @brief Insert tabulation
   #############################################################################
