@@ -53,6 +53,6 @@ if __name__ == "__main__":
 chmod +x /usr/bin/pygtkeditor"""
 
     print p
-    r = p.generate("2.4.1","1",changelog=" * Fix redo",tar=True,dsc=True,changes=True,build=False,src=True)
+    r = p.generate("2.4.2","1",changelog=" * Add duplicate line feature\n * Add replace tabs features",tar=True,dsc=True,changes=True,build=False,src=True)
     print r
 #scp *2.4.0-2* khertan@garage.maemo.org:/var/www/extras-devel/incoming-builder/diablo
\ No newline at end of file
