@@ -286,9 +286,25 @@ class pygtkeditor_window(hildon.Window):
     new_menuitem.show ()
     editmenu.append (new_menuitem)
 
+    new_menuitem = gtk.MenuItem ("Duplicate current line")
+    key, mod = gtk.accelerator_parse("D")
+    new_menuitem.add_accelerator("activate", accel_group, key, gtk.gdk.CONTROL_MASK, gtk.ACCEL_VISIBLE)
+    new_menuitem.connect ("activate", self.cb_tb_dup_line)
+    new_menuitem.show ()
+    editmenu.append (new_menuitem)
+    
     item = gtk.SeparatorMenuItem ()
     item.show ()
     editmenu.append (item)
+    
+    new_menuitem = gtk.MenuItem ("Replace tab by space")
+    new_menuitem.connect ("activate", self.cb_tb_rep_tabs)
+    new_menuitem.show ()
+    editmenu.append (new_menuitem)    
+    
+    item = gtk.SeparatorMenuItem ()
+    item.show ()
+    editmenu.append (item)    
 
     new_menuitem = gtk.ImageMenuItem (gtk.STOCK_FIND, accel_group)
     new_menuitem.connect ("activate", self.onShowFind)
@@ -428,6 +444,20 @@ class pygtkeditor_window(hildon.Window):
     start, end = textbuffer.get_bounds()
     textbuffer.select_range(start,end)
 
+  ###############################################################################
+  # @brief duplicate currrent line
+  ###############################################################################
+  def cb_tb_dup_line(self,widget):
+    id_page = self.notebook.get_current_page()
+    self.textview_list[id_page].duplicate_line() 
+    
+  ###############################################################################
+  # @brief Replace tabs by space
+  ###############################################################################
+  def cb_tb_rep_tabs(self,widget):
+    id_page = self.notebook.get_current_page()
+    self.textview_list[id_page].replace_tabs() 
+        
   ###############################################################################
   # @brief Open recent menu call back
   ###############################################################################
@@ -970,7 +1000,7 @@ class pygtkeditor_window(hildon.Window):
     dialog.set_logo_icon_name("pygtkeditor")
     dialog.set_authors(("Benoit HERVIER\n aka Khertan","","Thanks to :","Alterego for his help","Damien Moore for his patch"))
     dialog.set_comments('A source code editor for Maemo')
-    dialog.set_version("v2.4.1")
+    dialog.set_version("2.4.2")
     dialog.set_license("This program is free software; you can redistribute it and/or\nmodify it under the terms of the GNU General Public License\nas published by the Free Software Foundation; either version 2\nof the License, or (at your option) any later version.")
     dialog.set_copyright("By Benoit HERVIER (aka Khertan)")
     dialog.set_website("http://khertan.net/")
